import java.sql.*;
import javax.swing.table.*;

public class ResultSetTableModel extends AbstractTableModel {
	private Connection verbindung;
	private boolean verbunden;
	private Statement selectAnweisung;
	private ResultSet abfrageErgebnis;
	private ResultSetMetaData metaData;
	private int nZeilen;

	public ResultSetTableModel(String treiber, String url, String userid, String passwd, String tabelle) 
		throws SQLException, ClassNotFoundException {         
		// Datenbanktreiber laden
		Class.forName(treiber);
		// Verbindung zur Datenbank herstellen
		verbindung = DriverManager.getConnection(url, userid, passwd);
		verbunden = true;
		// Statement-Objekt erzeugen
		selectAnweisung = verbindung.createStatement(
			ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_UPDATABLE);
		neueAbfrage(tabelle);
	}

	public int getRowCount() {
		if (!verbunden) 
			return -1;
		else
			return nZeilen;
	}   
   
	public int getColumnCount() {
		if (!verbunden)
			return 0;
		try {
			return metaData.getColumnCount(); 
		} catch (SQLException e) {
			return 0;
		}
	}

	public Object getValueAt(int row, int col) {
		if (!verbunden)
			return null;
		try {
			abfrageErgebnis.absolute(row+1);
		    return abfrageErgebnis.getObject(col+1);
		} catch (SQLException e) {
			return null;
		}
	}

	public void setValueAt(Object obj, int row, int col) {
		if (!verbunden)
			return;
		try {
			abfrageErgebnis.absolute(row+1);
			abfrageErgebnis.updateObject(col+1, obj);
			abfrageErgebnis.updateRow();
		} catch (SQLException e) {
			e.printStackTrace();
			return;
		}
	}

	public boolean isCellEditable(int row, int col) {
		return true;
	}
	
	public String getColumnName(int col) {
		if (!verbunden)
			return "";
		try {
			return metaData.getColumnName(col+1);  
		} catch (SQLException e) {
			return "";
		}
	}
	
	public boolean neueAbfrage(String tabelle) { 
		if (!verbunden) 
			return false;
		try {
			abfrageErgebnis = selectAnweisung.executeQuery("SELECT * FROM "+tabelle);
			metaData = abfrageErgebnis.getMetaData();
		
			abfrageErgebnis.last();
			nZeilen = abfrageErgebnis.getRow();      
		  
			fireTableStructureChanged();
			return true;
		} catch (SQLException e) {
			return false;
		}
	}
              
	public void trennen() {              
		if (!verbunden)                  
			return;
		try {                                            
			selectAnweisung.close();                        
			verbindung.close();                       
		} catch (SQLException e) {                                            
		}                               
		finally {                                            
			verbunden = false;              
		}                             
	}          
}