import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.text.DecimalFormat;

class EuroKonverter extends JFrame {
	JLabel eingabeLabel, ausgabeLabel;
	JTextField eingabeFeld, ausgabeFeld;	
	JPanel panLinks, panRechts, panRechtsOben, panRechtsUnten;
    JButton ende, konvert;

	int richtung = 1;

	//Wird zum Erkennung berbreiter Ausgaben bentigt:
	FontMetrics fm;
	int maxAusgabeBreite;
	
	JRadioButton euro2dm, dm2euro;
	ButtonGroup rbGroup;

	DecimalFormat form = new DecimalFormat("0.00");

    EuroKonverter() {
        super("Euro-Konverter");
        Container cont = getContentPane();
		
		panLinks = new JPanel();
		panLinks.setLayout(new GridLayout(0, 1));
		panLinks.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		cont.add(panLinks, BorderLayout.WEST);

		// Dem Unicode-Zeichen \u27a0 entspricht ein horizontaler Pfeil. 
		dm2euro = new JRadioButton("DM "+'\u27a0'+" Euro", true);
   		dm2euro.setFocusable(false);

		euro2dm = new JRadioButton("Euro "+'\u27a0'+" DM", false);
   		euro2dm.setFocusable(false);
				
		rbGroup = new ButtonGroup();
		rbGroup.add(euro2dm);
		rbGroup.add(dm2euro);
		
		RadioHandler rbHandler = new RadioHandler();
		euro2dm.addItemListener(rbHandler);
		dm2euro.addItemListener(rbHandler);

        ende = new JButton("Ende");
   		ende.setFocusable(false);
        ende.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                System.exit(0);
            }
        });

		panLinks.add(dm2euro);
		panLinks.add(euro2dm);
		panLinks.add(ende);

		panRechts = new JPanel();
		panRechts.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		panRechts.setLayout(new GridLayout(0, 1));
		cont.add(panRechts, BorderLayout.CENTER);

		panRechtsOben = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panRechtsOben.setBorder(BorderFactory.createEmptyBorder(2, 2, 2, 2));
		panRechts.add(panRechtsOben);

		panRechtsUnten = new JPanel(new FlowLayout(FlowLayout.LEFT));
		panRechtsUnten.setBorder(BorderFactory.createEmptyBorder(2, 2, 2, 2));
		panRechts.add(panRechtsUnten);

		eingabeFeld = new JTextField("", 15);
   		eingabeFeld.requestFocus();
		eingabeFeld.setHorizontalAlignment(JTextField.RIGHT);
		panRechtsOben.add(eingabeFeld);

		eingabeLabel = new JLabel("DM");
		panRechtsOben.add(eingabeLabel);
		
		ausgabeFeld = new JTextField("", 15);
   		ausgabeFeld.setEditable(false);
   		ausgabeFeld.setFocusable(false);
   		ausgabeFeld.setHorizontalAlignment(JTextField.RIGHT);
		panRechtsUnten.add(ausgabeFeld);

		ausgabeLabel = new JLabel("Euro");
		panRechtsUnten.add(ausgabeLabel);

        konvert = new JButton("Konvertieren");
        konvert.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
          		String eingabe = eingabeFeld.getText(), ausgabe;
          		if (eingabe.length() == 0) {
          			konvert.transferFocus();
          			return;
          		}
          		double factor = 1.95583;
          		if (richtung == 0) {
          			factor = 1.95583;
          		}
          		else {
          			factor = 1.0/1.95583;
          		}
      			try {
					// Dies ermglicht die Eingabe des Kommas als Dezimaltrennzeichen:
	      			eingabe = eingabe.replace(',','.');
	      			double wert = Double.parseDouble(eingabe);
	      			wert *= factor;
	      			ausgabe = form.format(wert);
	      			if (fm.stringWidth(ausgabe) <= maxAusgabeBreite)
						ausgabeFeld.setText(ausgabe);
					else
						ausgabeFeld.setText("Ergebnis zu breit!");
      			} catch (Exception ex) {
					meldeFehler(ex);
      			}
				konvert.transferFocus();
				eingabeFeld.selectAll();
            }
        });
   		getRootPane().setDefaultButton(konvert);
		panRechts.add(konvert);


		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setSize(320, 150);
        setResizable(false);
        setVisible(true);

		//Wird zum Erkennung berbreiter Ausgaben bentigt:
		fm = getFontMetrics(getFont());
		maxAusgabeBreite = ausgabeFeld.getWidth();
    }

	private void meldeFehler(Exception ex) {
		JOptionPane.showMessageDialog(this, "Fehler bei der Konvertierung: "+
		ex.toString(), "Fehler", JOptionPane.ERROR_MESSAGE);
	}

    public static void main(String[] args) {
        new EuroKonverter();
    }

	class RadioHandler implements ItemListener {
		public void itemStateChanged(ItemEvent e) {
			eingabeFeld.setText("");
			ausgabeFeld.setText("");
			if (e.getSource() == euro2dm) {
				eingabeLabel.setText("Euro");
				ausgabeLabel.setText("DM");
				richtung = 0;
			} else if (e.getSource() == dm2euro) {
				eingabeLabel.setText("DM");
				ausgabeLabel.setText("Euro");
				richtung = 1;
			}
		}
	}
}
